pub struct DICompositeType<'ctx> { /* private fields */ }Expand description
A wrapper around an array of types, such as a union or struct.
Implementations
Sourceimpl<'ctx> DICompositeType<'ctx>
impl<'ctx> DICompositeType<'ctx>
pub fn as_type(&self) -> DIType<'ctx>
Sourcepub fn as_mut_ptr(&self) -> LLVMMetadataRef
pub fn as_mut_ptr(&self) -> LLVMMetadataRef
Acquires the underlying raw pointer belonging to this DICompositeType type.